@@ -10,16 +10,18 @@ pub struct AwsConfig<'a> {
     pub style: &'a str,
     pub disabled: bool,
     pub region_aliases: HashMap<String, &'a str>,
+    pub expiration_symbol: &'a str,
 }
 
 impl<'a> Default for AwsConfig<'a> {
     fn default() -> Self {
         AwsConfig {
-            format: "on [$symbol($profile )(\\($region\\) )]($style)",
+            format: "on [$symbol($profile )(\\($region\\) )(\\[$duration\\])]($style)",
             symbol: "☁️  ",
             style: "bold yellow",
             disabled: false,
             region_aliases: HashMap::new(),
+            expiration_symbol: "X",
         }
     }
 }
