@@ -73,9 +73,11 @@ pub const PROMPT_ORDER: &[&str] = &[
     "aws",
     "gcloud",
     "openstack",
+    "azure",
     "env_var",
     "crystal",
     "custom",
+    "sudo",
     "cmd_duration",
     "line_break",
     "jobs",
