@@ -5,6 +5,7 @@ use std::collections::BTreeSet;
 use std::fmt::{self, Debug, Write as FmtWrite};
 use std::io::{self, Write};
 use std::time::Duration;
+use terminal_size::terminal_size;
 use unicode_segmentation::UnicodeSegmentation;
 use unicode_width::UnicodeWidthChar;
 
@@ -61,7 +62,7 @@ pub fn prompt(args: ArgMatches) {
 }
 
 pub fn get_prompt(context: Context) -> String {
-    let config = context.config.get_root_config();
+    let config = &context.root_config;
     let mut buf = String::new();
 
     match std::env::var_os("TERM") {
@@ -108,7 +109,7 @@ pub fn get_prompt(context: Context) -> String {
     let mut root_module = Module::new("Starship Root", "The root module", None);
     root_module.set_segments(
         formatter
-            .parse(None)
+            .parse(None, Some(&context))
             .expect("Unexpected error returned in root format variables"),
     );
 
@@ -224,8 +225,8 @@ pub fn explain(args: ArgMatches) {
     // Overall a line looks like this: " "{module value}" ({xxxms})  -  {description}".
     const PADDING_WIDTH: usize = 11;
 
-    let desc_width = term_size::dimensions()
-        .map(|(w, _)| w)
+    let desc_width = terminal_size()
+        .map(|(w, _)| w.0 as usize)
         // Add padding length to module length to avoid text overflow. This line also assures desc_width >= 0.
         .map(|width| width - std::cmp::min(width, max_module_width + PADDING_WIDTH));
 
@@ -411,10 +412,10 @@ fn all_modules_uniq(module_list: &BTreeSet<String>) -> Vec<String> {
 /// Load the correct formatter for the context (ie left prompt or right prompt)
 /// and the list of all modules used in a format string
 fn load_formatter_and_modules<'a>(context: &'a Context) -> (StringFormatter<'a>, BTreeSet<String>) {
-    let config = context.config.get_root_config();
+    let config = &context.root_config;
 
-    let lformatter = StringFormatter::new(config.format);
-    let rformatter = StringFormatter::new(config.right_format);
+    let lformatter = StringFormatter::new(&config.format);
+    let rformatter = StringFormatter::new(&config.right_format);
     if lformatter.is_err() {
         log::error!("Error parsing `format`")
     }
@@ -453,6 +454,7 @@ mod test {
                 format=">\n>"
             }),
         };
+        context.root_config.right_format = "$character".to_string();
         context.right = true;
 
         let expected = String::from(">>"); // should strip new lines
